#include <iostream>
#include <cstdint>
#include <vector>
#include <string>

constexpr int64_t base = 1000000;

int64_t parseInt(const std::string &s)
{
    int64_t result = 0;
    int64_t sign = 1;
    for(int i=0; i<s.length(); i++)
    {
        if(s[i] == '.')
            continue;
        else if(s[i] == '-')
            sign = -1;
        else
        {
            result *= 10;
            result += (s[i] - '0');
        }
    }
    return sign * result;
}   

int64_t robustDivision(int64_t x, int64_t denom)
{
    if(x >= 0)
        return x / denom;
    return (x - denom + 1) / denom;
} 

void collectSemiIntegerPoints(int64_t x1, int64_t y1, int64_t x2, int64_t y2, std::vector<int64_t> &result)
{
    if(x1 > x2)
    {
        std::swap(x1, x2);
        std::swap(y1, y2);
    }
    int start = robustDivision(x1, base);
    int end = robustDivision(x2, base);
    
    for(int i=start+1; i<=end; i++)
    {
        int64_t x = i*base;
        int64_t num = x - x1;
        int64_t denom = x2 - x1;
        int64_t y = y1 + robustDivision(num * (y2 - y1), denom);
        result.push_back(robustDivision(y, base));
    }
}

int main()
{
    int N;
    std::cin >> N;
    std::vector<int64_t> x(N);
    std::vector<int64_t> y(N);
    for(int i=0; i<N; i++)
    {
        std::string xs, ys;
        std::cin >> xs >> ys;
        x[i] = parseInt(xs);
        y[i] = parseInt(ys);
    }
    
    std::vector<int64_t> set1;
    std::vector<int64_t> set2;    
    
    for(int i=0; i<N; i++)
    {
        int64_t nexti = (i+1) % N;
        collectSemiIntegerPoints(x[i], y[i], x[nexti], y[nexti], x[i] < x[nexti] ? set1 : set2);
        collectSemiIntegerPoints(y[i], x[i], y[nexti], x[nexti], y[i] < y[nexti] ? set1 : set2); 
    }
    
    std::cout << set1.size() << std::endl;
    for(auto i : set1)
        std::cout << i << std::endl;
}
